==> pyannote.parser-0.2.3.tar.gz: pyannote.parser-0.2.3/pyannote/parser/timeline/uem.py <==
#!/usr/bin/env python
# encoding: utf-8

# The MIT License (MIT)

# Copyright (c) 2014 CNRS

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# AUTHORS
# Hervé BREDIN - http://herve.niderb.fr

from __future__ import unicode_literals

from pyannote.core import Segment
from pyannote.core import PYANNOTE_URI

from base import TimelineParser


class UEMParser(TimelineParser):
    """UEM (Unpartitioned Evaluation Map) is a file format used to create
    an index specifying time regions within a recorded waveform.

    http://www.itl.nist.gov/iad/mig/tests/rt/
    """

    @classmethod
    def file_extensions(cls):
        return ['uem']

    def fields(self):
        return [PYANNOTE_URI,
                '1',
                'start',
                'end']

    def comment(self):
        return ';'

    def get_segment(self, row):
        return Segment(row['start'], row['end'])

    def _append(self, timeline, f, uri):

        format = '%s 1 %%g %%g\n' % (uri)
        for segment in timeline:
            f.write(format % (segment.start, segment.end))

==> pyannote.parser-0.4.2.tar.gz: pyannote.parser-0.4.2/pyannote/parser/timeline/uem.py <==
#!/usr/bin/env python
# encoding: utf-8

# The MIT License (MIT)

# Copyright (c) 2014-2015 CNRS

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# AUTHORS
# Hervé BREDIN - http://herve.niderb.fr

from __future__ import unicode_literals

from pyannote.core import Segment
from pyannote.core import PYANNOTE_URI

from .base import TimelineParser


class UEMParser(TimelineParser):
    """UEM (Unpartitioned Evaluation Map) is a file format used to create
    an index specifying time regions within a recorded waveform.

    http://www.itl.nist.gov/iad/mig/tests/rt/
    """

    @classmethod
    def file_extensions(cls):
        return ['uem']

    def fields(self):
        return [PYANNOTE_URI,
                '1',
                'start',
                'end']

    def comment(self):
        return ';'

    def get_segment(self, row):
        return Segment(row['start'], row['end'])

    def _append(self, timeline, f, uri):

        format = '%s 1 %%g %%g\n' % (uri)
        for segment in timeline:
            f.write(format % (segment.start, segment.end))
